@@ -18,11 +18,11 @@
  *                - Mosaic support     - Roland Marcus Rutschmann          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-dicm.c,v 1.165 2004/10/31 23:16:07 enlf Exp $
+/* $Id: m-dicm.c,v 1.167 2005/05/16 07:35:00 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2004 by Erik Nolf
+   Copyright (C) 1997-2005 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -444,7 +444,7 @@ char *MdcHandleMosaic(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom, IMAGE *image)
   bytes_per_mosaic = bytes * width;
   bytes_per_old_img_line = bytes * fi->mwidth;
   nr_of_pics_per_line = bytes_per_old_img_line / bytes_per_mosaic;
-  bytes_per_y_plane = width * bytes_per_old_img_line;
+  bytes_per_y_plane = height * bytes_per_old_img_line;
   for (sl=0; sl<number; sl++) { 
      if (dicom->mosaic_interlaced == MDC_YES) {
        if (sl%2 == 0) { 
@@ -458,7 +458,7 @@ char *MdcHandleMosaic(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom, IMAGE *image)
      x = s % nr_of_pics_per_line;
      y = s / nr_of_pics_per_line;
      offset = (y * bytes_per_y_plane) + (x * bytes_per_mosaic);
-     for (yline=0; yline < width; yline++) {
+     for (yline=0; yline < height; yline++) {
         p = pmosaic + sl*size + yline*bytes_per_mosaic;
         pdata = (Uint8 *)pimg->data.gray + offset;
         memcpy(p,pdata,bytes_per_mosaic);
