@@ -37,11 +37,11 @@
  *                MdcCleanUpFI()        - Clean up FILEINFO struct         *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-structs.c,v 1.62 2004/10/16 20:36:35 enlf Exp $ 
+/* $Id: m-structs.c,v 1.64 2005/05/16 07:35:02 enlf Exp $ 
  */
 
 /*
-   Copyright (C) 1997-2004 by Erik Nolf
+   Copyright (C) 1997-2005 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -677,8 +677,11 @@ char *MdcCopyFI(FILEINFO *dest, FILEINFO *src, int COPY_IMAGES, int KEEP_FILES)
     dest->ofp_raw = src->ofp_raw;
   }
 
-  strncpy(dest->ipath,src->ipath,MDC_MAX_PATH);
-  strncpy(dest->opath,src->opath,MDC_MAX_PATH);
+  memcpy(dest->ipath,src->ipath,MDC_MAX_PATH);
+  memcpy(dest->opath,src->opath,MDC_MAX_PATH);
+
+  MdcSplitPath(dest->ipath,dest->idir,dest->ifname);
+  MdcSplitPath(dest->opath,dest->odir,dest->ofname);
 
   dest->iformat = src->iformat;
   dest->oformat = src->oformat;
